import Vue from 'vue';
import Vuex from 'vuex';
import axios from 'axios';

Vue.use(Vuex);
export default {
  namespaced: true,
  state: {
    status: '123',
    token: localStorage.getItem('token') || '',
    user: {},
  },
  mutations: {
    auth_request(state) {
      state.status = 'loading';
    },
    auth_success(state, token, user) {
      state.status = 'success';
      state.token = token;
      state.user = user;
    },
    auth_error(state) {
      state.status = 'error';
    },
    logout(state) {
      state.status = '';
      state.token = '';
    },
  },
  getters: {
    isLoggenIn: state => !!state.token,
    authStatus: state => state.status,
  },
  actions: {
    login({
      commit,
    }, user) {
      return new Promise((reject) => {
        commit('auth_request');
        axios({
          url: '/api/register/authenticate',
          data: user,
          method: 'POST',
        })
          .then((resp) => {
            console.log(resp.data);
            localStorage.setItem('token', resp.data.token);
            commit('auth_success', resp.data.token, resp.data);
          })
          .catch((err) => {
            commit('auth_error');
            localStorage.removeItem('token');
            reject(err);
          });
      });
    },
    logout({
      commit,
    }) {
      return new Promise(() => {
        commit('logout');
        console.log('What');
        localStorage.removeItem('token');
        delete axios.defaults.headers.common.Authorization;
      });
    },
  },
};
